@@ -10,18 +10,15 @@ use Carp qw(croak carp);
 #######################
 # LOAD CPAN MODULES
 #######################
-use Params::Validate qw(validate_with :types);
+use Params::Validate qw(validate_with OBJECT SCALAR);
 use Object::Tiny qw(
-  session
-  config
-  change_keys
-  img_backdrop_sizes
-  img_base_url
-  img_secure_base_url
-  img_poster_sizes
-  img_profile_sizes
-  img_logo_sizes
-  img_default_size
+    session
+    config
+    img_backdrop_sizes
+    img_base_url
+    img_poster_sizes
+    img_profile_sizes
+    img_default_size
 );
 
 #######################
@@ -60,13 +57,9 @@ sub new {
     $self->{img_backdrop_sizes} = $config->{images}->{backdrop_sizes} || [];
     $self->{img_poster_sizes}   = $config->{images}->{poster_sizes} || [];
     $self->{img_profile_sizes}  = $config->{images}->{profile_sizes} || [];
-    $self->{img_logo_sizes}     = $config->{images}->{logo_sizes} || [];
     $self->{img_base_url}       = $config->{images}->{base_url} || q();
-    $self->{img_secure_base_url}
-      = $config->{images}->{secure_base_url} || q();
-    $self->{change_keys} = $config->{change_keys} || [];
 
-  return $self;
+    return $self;
 } ## end sub new
 
 #######################
